@@ -1,17 +1,24 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import annotations
 
+from collections.abc import Generator
+
+from git_code_debt.file_diff_stat import FileDiffStat
 from git_code_debt.file_diff_stat import SpecialFileType
 from git_code_debt.file_diff_stat import Status
 from git_code_debt.metric import Metric
 from git_code_debt.metrics.base import DiffParserBase
 from git_code_debt.metrics.base import MetricInfo
+from git_code_debt.repo_parser import Commit
 
 
 class SymlinkCount(DiffParserBase):
     """Counts the number of symlinks in the repository."""
 
-    def get_metrics_from_stat(self, _, file_diff_stats):
+    def get_metrics_from_stat(
+            self,
+            _: Commit,
+            file_diff_stats: tuple[FileDiffStat, ...],
+    ) -> Generator[Metric]:
         symlink_delta = 0
 
         for file_diff_stat in file_diff_stats:
@@ -29,5 +36,5 @@ class SymlinkCount(DiffParserBase):
         if symlink_delta:
             yield Metric(type(self).__name__, symlink_delta)
 
-    def get_metrics_info(self):
+    def get_metrics_info(self) -> list[MetricInfo]:
         return [MetricInfo.from_class(type(self))]
