@@ -1,7 +1,8 @@
+from __future__ import annotations
+
 import itertools
-from typing import Generator
-from typing import Iterable
-from typing import Tuple
+from collections.abc import Generator
+from collections.abc import Iterable
 from typing import TypeVar
 
 T = TypeVar('T')
@@ -10,7 +11,7 @@ T = TypeVar('T')
 def chunk_iter(
         iterable: Iterable[T],
         n: int,
-) -> Generator[Tuple[T, ...], None, None]:
+) -> Generator[tuple[T, ...]]:
     """Yields an iterator in chunks
 
     For example you can do
